import java.awt.GridLayout;
import java.awt.event.*;
import javax.swing.*;

/**
 * GUI of the program
 */
public class StayOnlineGui extends JFrame implements ActionListener, WindowListener {
    
    static final long serialVersionUID = 1L;
    
    StayOnlineHelpGui help;
    StayOnlineOptGui opt;
    StayOnlineData data = new StayOnlineData();
    StayOnlineSend send;
    
    JTextField tfText;
    JTextField tfTime;
    
    JButton bStart;
    JButton bHelp;
    JButton bOpt;
    JButton bQuit;
    
    boolean run = true;
    
    /**
     * Sets all graphical components and loads data with StayOnlineRW
     */
    public StayOnlineGui() {
        super("StayOnline");
        StayOnlineRw.loadSettings(data);
        setSize(280, 130);
        GridLayout grid = new GridLayout(4, 2);
        
        JPanel pMain = new JPanel(grid);
        
        JLabel lText = new JLabel("Text");
        tfText = new JTextField(data.getText(), 10);
        
        JLabel lTime = new JLabel("Zeit in s");
        tfTime = new JTextField(data.getTimeString(), 30);
        
        bStart = new JButton("Start");
        bHelp = new JButton("Hilfe");
        bOpt = new JButton("Einstellungen");
        bQuit = new JButton("Beenden");
        
        bStart.addActionListener(this);
        bHelp.addActionListener(this);
        bOpt.addActionListener(this);
        bQuit.addActionListener(this);
        addWindowListener(this);
        
        pMain.add(lText);
        pMain.add(tfText);
        pMain.add(lTime);
        pMain.add(tfTime);
        pMain.add(bStart);
        pMain.add(bHelp);
        pMain.add(bOpt);
        pMain.add(bQuit);
        
        setContentPane(pMain);
        setVisible(true);
    }
    
    public void windowClosing(WindowEvent event) {
        System.exit(0);
    }
    
    public void windowClosed(WindowEvent event) {
    }
    
    public void windowDeiconified(WindowEvent event) {
    }
    
    public void windowIconified(WindowEvent event) {
    }
    
    public void windowActivated(WindowEvent event) {
    }
    
    public void windowDeactivated(WindowEvent event) {
    }
    
    public void windowOpened(WindowEvent event) {
    }
    
    /**
     * Handles actionEvents from Buttons
     */
    public void actionPerformed(ActionEvent evt) {
        
        Object src = evt.getSource();
        if(src == bStart) {
            bStartPressed();
        } else if(src == bHelp) {
            bHelpPressed();
        } else if(src == bOpt) {
            bOptPressed();
        } else if(src == bQuit) {
            System.exit(0);
        } else
            System.out.println("keinen knopf gedrueckt");
        
        repaint();
    }
    
    /**
     * If bStart is pressed this function is called. It saves the settings and starts the sending thread
     */
    public void bStartPressed() {
        
        if(run) {
            getData();
            StayOnlineRw.saveSettings(data);
            send = new StayOnlineSend(data, this);
            run = false;
            tfTime.setEnabled(false);
            
            bStart.setText("Stop");
            bStart.repaint();
        } else {
            send.halt();
            run = true;
            tfTime.setEnabled(true);
            tfTime.setText(data.getTimeString());
            bStart.setText("Start");
            bStart.repaint();
        }
        
    }
    
    /**
     * Is called when bHelp is pressed. Creates a new instance of the HelpGui
     */
    public void bHelpPressed() {
        help = new StayOnlineHelpGui();
    }
    
    /**
     * Is called when bOpt is pressed. Calls getData and creates a new instance of the OptGui
     */
    public void bOptPressed() {
        getData();
        opt = new StayOnlineOptGui(data, this);
    }
    
    /**
     * Sets the Time TextField
     * 
     * @param t String with seconds to wait
     */
    public void setTime(String t) {
        tfTime.setText(t);
    }
    
    /**
     * Sets the Text TextField
     * 
     * @param t textstring to be send
     */
    public void setText(String t) {
        tfText.setText(t);
    }
    
    /**
     * @return the String from TextField that will be send
     */
    public String getText() {
        return tfText.getText();
    }
    
    /**
     * Writes the values of the textFields Time and Text in the data-structure
     */
    void getData() {
        data.setText(tfText.getText());
        data.setTime(Integer.parseInt(tfTime.getText()));
    }
}